| Title: | Rounded Bar Plots |
| Version: | 0.1.0 |
| Author: | Botan Ağın [aut, cre, cph] |
| Maintainer: | Botan Ağın <aginbotan@gmail.com> |
| Description: | Creates bar plots with rounded corners using 'ggplot2'. The code in this package was adapted from a solution provided by Stack Overflow user 'sthoch' in the following post https://stackoverflow.com/questions/62176038/r-ggplot2-bar-chart-with-round-corners-on-top-of-bar. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.2 |
| Imports: | ggplot2, grid |
| URL: | https://github.com/botan/ggrounded, https://botan.github.io/ggrounded/ |
| BugReports: | https://github.com/botan/ggrounded/issues |
| Suggests: | covr, testthat (≥ 3.0.0), vdiffr |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-04-10 12:01:47 UTC; botan |
| Repository: | CRAN |
| Date/Publication: | 2026-04-10 12:20:02 UTC |
Bar plot with rounded corners
Description
Create a bar plot with rounded corners using
'ggplot2'. geom_col_rounded() and geom_bar_rounded() are extensions of
the ggplot2::geom_col() and ggplot2::geom_bar() functions and they
provide additional aesthetics for more visually appealing outputs.
Usage
geom_bar_rounded(
mapping = NULL,
data = NULL,
position = ggplot2::position_stack(reverse = TRUE),
radius = 0.2,
...,
width = NULL,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_col_rounded(
mapping = NULL,
data = NULL,
position = ggplot2::position_stack(reverse = TRUE),
radius = 0.2,
...,
width = NULL,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
Arguments
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
position |
Position adjustment, either as a string naming the adjustment
(e.g. |
radius |
A normalized rounding amount between 0 and 1. Use |
... |
Other arguments passed on to |
width |
Bar width. If not supplied, the default is to use the width of 90% of the resolution of the data. |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
Value
A ggplot object.
Note
The code in this function was adapted from a solution provided by Stack Overflow user 'sthoch' in the following post: https://stackoverflow.com/questions/62176038/r-ggplot2-bar-chart-with-round-corners-on-top-of-bar
Examples
library(ggplot2)
ggplot(data.frame(x = letters[1:3], y = c(2.3, 1.9, 3.2)), aes(x, y)) +
geom_col_rounded()
ggplot(data.frame(x = letters[1:3], y = c(2.3, 1.9, 3.2)), aes(x, y)) +
geom_col_rounded(radius = 1)
ggplot(mpg, aes(class)) +
geom_bar_rounded()
Histogram with rounded bars
Description
Create a histogram with rounded corners using
'ggplot2'. geom_histogram_rounded() is an extension of the
ggplot2::geom_histogram() function and uses the same binning
parameters as ggplot2::stat_bin() while drawing bars with rounded
corners.
Usage
geom_histogram_rounded(
mapping = NULL,
data = NULL,
position = "stack",
radius = 0.2,
...,
binwidth = NULL,
bins = NULL,
center = NULL,
boundary = NULL,
closed = c("right", "left"),
pad = FALSE,
breaks = NULL,
drop = "none",
orientation = NA,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
Arguments
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
position |
Position adjustment, either as a string naming the adjustment
(e.g. |
radius |
A normalized rounding amount between 0 and 1. Use |
... |
Other arguments passed on to |
binwidth |
The width of the bins. The default uses 30 bins that cover the range of the data. You should usually override this value, exploring multiple widths to find the best to illustrate the stories in your data. |
bins |
Number of bins. Overridden by |
center, boundary |
Bin position specifiers passed to
|
closed |
One of |
pad |
If |
breaks |
A numeric vector of bin boundaries. |
drop |
Controls whether empty bins are dropped. Passed to
|
orientation |
The orientation of the layer. Passed to
|
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
Value
A ggplot object.
Examples
library(ggplot2)
ggplot(faithful, aes(waiting)) +
geom_histogram_rounded()
ggplot(faithful, aes(waiting)) +
geom_histogram_rounded(bins = 10, radius = 1)